@@ -1,27 +1,11 @@
 /*
   This file is part of the KDE reminder agent.
 
-  Copyright (c) 2000,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2008-2020 Allen Winter <winter@kde.org>
-  Copyright (c) 2009-2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2000, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2008-2020 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 2009-2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "config-korganizer.h"
@@ -112,12 +96,12 @@ bool ReminderTreeItem::operator<(const QTreeWidgetItem &other) const
     switch (treeWidget()->sortColumn()) {
     case 1:
     {         // happening datetime
-        const ReminderTreeItem *item = static_cast<const ReminderTreeItem *>(&other);
+        const auto *item = static_cast<const ReminderTreeItem *>(&other);
         return item->mHappening < mHappening;
     }
     case 2:
     {         // trigger datetime
-        const ReminderTreeItem *item = static_cast<const ReminderTreeItem *>(&other);
+        const auto *item = static_cast<const ReminderTreeItem *>(&other);
         return item->mTrigger < mTrigger;
     }
     default:
@@ -166,8 +150,8 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     QWidget *topBox = new QWidget(this);
     setWindowTitle(i18nc("@title:window", "Reminders"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("korgac")));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *buttonBox = new QDialogButtonBox(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(topBox);
     mOkButton = new QPushButton;
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -211,15 +195,14 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
                                   "Press this button to suspend the currently selected incidences.  "
                                   "The suspend interval is configurable by the Suspend duration settings."));
 
-    QVBoxLayout *topLayout = new QVBoxLayout(topBox);
+    auto *topLayout = new QVBoxLayout(topBox);
     // Try to keep the dialog small and non-obtrusive.
     // the user can resize down to the minimum
     setMinimumSize(280, 160);
     // take out some padding which makes it larger
     topLayout->setSpacing(2);
-    QMargins margins(0, 0, 0, 0);
-    topLayout->setContentsMargins(margins);
-    setContentsMargins(margins);
+    topLayout->setContentsMargins({});
+    setContentsMargins({});
 
     QLabel *label = new QLabel(
         i18nc("@label",
@@ -275,8 +258,8 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     mLastItem = nullptr;
 
     QWidget *suspendBox = new QWidget(topBox);
-    QHBoxLayout *suspendBoxHBoxLayout = new QHBoxLayout(suspendBox);
-    suspendBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
+    auto *suspendBoxHBoxLayout = new QHBoxLayout(suspendBox);
+    suspendBoxHBoxLayout->setContentsMargins({});
     topLayout->addWidget(suspendBox);
 
     QLabel *l = new QLabel(i18nc("@label:spinbox", "Suspend &duration:"), suspendBox);
@@ -345,7 +328,7 @@ ReminderTreeItem *AlarmDialog::searchByItem(const Akonadi::Item &incidence)
     ReminderTreeItem *found = nullptr;
     QTreeWidgetItemIterator it(mIncidenceTree);
     while (*it) {
-        ReminderTreeItem *item = static_cast<ReminderTreeItem *>(*it);
+        auto *item = static_cast<ReminderTreeItem *>(*it);
         if (item->mIncidence == incidence) {
             found = item;
             break;
@@ -498,7 +481,7 @@ void AlarmDialog::dismiss(const ReminderList &selections)
 
 void AlarmDialog::edit()
 {
-    ReminderList selection = selectedItems();
+    const ReminderList selection = selectedItems();
     if (selection.count() == 1) {
         Incidence::Ptr incidence = CalendarSupport::incidence(selection.first()->mIncidence);
         if (!mCalendar->hasRight(selection.first()->mIncidence,
@@ -552,7 +535,7 @@ void AlarmDialog::suspend()
         if ((*it)->isSelected() && !(*it)->isDisabled()) {   //suspend selected, non-suspended reminders
             (*it)->setSelected(false);
             (*it)->setDisabled(true);
-            ReminderTreeItem *item = static_cast<ReminderTreeItem *>(*it);
+            auto *item = static_cast<ReminderTreeItem *>(*it);
             item->mRemindAt = QDateTime::currentDateTime().addSecs(unit * mSuspendSpin->value());
             item->mHappening = item->mRemindAt;
             item->mNotified = false;
@@ -589,7 +572,7 @@ void AlarmDialog::setTimer()
 
     QTreeWidgetItemIterator it(mIncidenceTree);
     while (*it) {
-        ReminderTreeItem *item = static_cast<ReminderTreeItem *>(*it);
+        auto *item = static_cast<ReminderTreeItem *>(*it);
         if (item->mRemindAt > QDateTime::currentDateTime()) {
             const int secs = QDateTime::currentDateTime().secsTo(item->mRemindAt);
             nextReminderAt = nextReminderAt <= 0 ? secs : qMin(nextReminderAt, secs);
@@ -626,7 +609,7 @@ void AlarmDialog::show()
     // select the first item that hasn't already been notified
     QTreeWidgetItemIterator it(mIncidenceTree);
     while (*it) {
-        ReminderTreeItem *item = static_cast<ReminderTreeItem *>(*it);
+        auto *item = static_cast<ReminderTreeItem *>(*it);
         if (!item->mNotified && !item->isDisabled()) {
             (*it)->setSelected(true);
             break;
@@ -680,7 +663,7 @@ void AlarmDialog::eventNotification()
 
     QTreeWidgetItemIterator it(mIncidenceTree);
     while (*it) {
-        ReminderTreeItem *item = static_cast<ReminderTreeItem *>(*it);
+        auto *item = static_cast<ReminderTreeItem *>(*it);
         ++it;
         if (item->isDisabled() || item->mNotified) {
             //skip suspended reminders or reminders that have been notified
@@ -801,7 +784,7 @@ void AlarmDialog::wakeUp()
         if (!firstItem) {
             firstItem = *it;
         }
-        ReminderTreeItem *item = static_cast<ReminderTreeItem *>(*it);
+        auto *item = static_cast<ReminderTreeItem *>(*it);
         Incidence::Ptr incidence = CalendarSupport::incidence(item->mIncidence);
 
         if (item->mRemindAt <= QDateTime::currentDateTime()) {
@@ -847,7 +830,7 @@ void AlarmDialog::slotSave()
 
     QTreeWidgetItemIterator it(mIncidenceTree);
     while (*it) {
-        ReminderTreeItem *item = static_cast<ReminderTreeItem *>(*it);
+        auto *item = static_cast<ReminderTreeItem *>(*it);
         KConfigGroup incidenceConfig(config,
                                      QStringLiteral("Incidence-%1").arg(numReminders + 1));
 
@@ -959,7 +942,7 @@ void AlarmDialog::showDetails(QTreeWidgetItem *item)
         return;
     }
 
-    ReminderTreeItem *reminderItem = dynamic_cast<ReminderTreeItem *>(item);
+    auto *reminderItem = dynamic_cast<ReminderTreeItem *>(item);
 
     if (!reminderItem) {
         mDetailView->setIncidence(Akonadi::Item());
@@ -1111,7 +1094,7 @@ bool AlarmDialog::openIncidenceEditorThroughKOrganizer(const Incidence::Ptr &inc
         int window = reply;
         KWindowSystem::minimizeWindow(winId());
         KWindowSystem::allowExternalProcessWindowActivation();
-        KWindowSystem::activateWindow(reinterpret_cast<WId>(window));
+        KWindowSystem::activateWindow(static_cast<WId>(window));
     }
 #else
     // TODO (mac)
