@@ -1,25 +1,9 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "aboutdata.h"
@@ -39,7 +23,7 @@ AboutData::AboutData()
                       "Copyright © 2000–2004, 2007 Cornelius Schumacher\n"
                       "Copyright © 2004–2005 Reinhold Kainhofer\n"
                       "Copyright © 2006–2012 Allen Winter\n"
-                      "Copyright © 2012–2019 KOrganizer authors"),
+                      "Copyright © 2012–2020 KOrganizer authors"),
                  QString(),
                  QStringLiteral("https://userbase.kde.org/KOrganizer"))
 {
