@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+  SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "koeventpopupmenutest.h"
@@ -46,10 +35,10 @@ void KoEventPopupMenuTest::createEventFromEvent()
 
     menu.setCalendar(calendar);
     menu.showIncidencePopup(item, QDate());
-    QAction *createevent = menu.findChild<QAction *>(QStringLiteral("createevent"));
+    auto *createevent = menu.findChild<QAction *>(QStringLiteral("createevent"));
     createevent->trigger();
 
-    IncidenceEditorNG::IncidenceDialog *dlg
+    auto *dlg
         = menu.findChild<IncidenceEditorNG::IncidenceDialog *>(QStringLiteral("incidencedialog"));
     QVERIFY(!dlg);
 }
@@ -66,10 +55,10 @@ void KoEventPopupMenuTest::createTodoFromTodo()
 
     menu.setCalendar(calendar);
     menu.showIncidencePopup(item, QDate());
-    QAction *createtodo = menu.findChild<QAction *>(QStringLiteral("createtodo"));
+    auto *createtodo = menu.findChild<QAction *>(QStringLiteral("createtodo"));
     createtodo->trigger();
 
-    IncidenceEditorNG::IncidenceDialog *dlg
+    auto *dlg
         = menu.findChild<IncidenceEditorNG::IncidenceDialog *>(QStringLiteral("incidencedialog"));
     QVERIFY(!dlg);
 }
@@ -94,12 +83,12 @@ void KoEventPopupMenuTest::createEventFromTodo()
 
     menu.setCalendar(calendar);
     menu.showIncidencePopup(item, QDate());
-    QAction *createevent = menu.findChild<QAction *>(QStringLiteral("createevent"));
+    auto *createevent = menu.findChild<QAction *>(QStringLiteral("createevent"));
     createevent->trigger();
-    IncidenceEditorNG::IncidenceDialog *dlg
+    auto *dlg
         = menu.findChild<IncidenceEditorNG::IncidenceDialog *>();
     QVERIFY(dlg);
-    IncidenceEditorNG::IncidenceEditor *editor
+    auto *editor
         = menu.findChild<IncidenceEditorNG::IncidenceEditor *>();
     QVERIFY(editor);
     KCalendarCore::Event::Ptr event(editor->incidence<KCalendarCore::Event>());
@@ -130,12 +119,12 @@ void KoEventPopupMenuTest::createTodoFromEvent()
 
     menu.setCalendar(calendar);
     menu.showIncidencePopup(item, QDate());
-    QAction *createtodo = menu.findChild<QAction *>(QStringLiteral("createtodo"));
+    auto *createtodo = menu.findChild<QAction *>(QStringLiteral("createtodo"));
     createtodo->trigger();
-    IncidenceEditorNG::IncidenceDialog *dlg
+    auto *dlg
         = menu.findChild<IncidenceEditorNG::IncidenceDialog *>();
     QVERIFY(dlg);
-    IncidenceEditorNG::IncidenceEditor *editor
+    auto *editor
         = menu.findChild<IncidenceEditorNG::IncidenceEditor *>();
     QVERIFY(editor);
     KCalendarCore::Todo::Ptr todo(editor->incidence<KCalendarCore::Todo>());
@@ -168,8 +157,8 @@ void KoEventPopupMenuTest::createNoteFromEvent()
 
     menu.setCalendar(calendar);
     menu.showIncidencePopup(item, QDate());
-    QAction *createnote = menu.findChild<QAction *>(QStringLiteral("createnote"));
-    CalendarSupport::NoteEditDialog *noteedit = menu.findChild<CalendarSupport::NoteEditDialog *>();
+    auto *createnote = menu.findChild<QAction *>(QStringLiteral("createnote"));
+    auto *noteedit = menu.findChild<CalendarSupport::NoteEditDialog *>();
     QVERIFY(!noteedit);
     createnote->trigger();
     noteedit = menu.findChild<CalendarSupport::NoteEditDialog *>();
@@ -206,9 +195,9 @@ void KoEventPopupMenuTest::createNoteFromTodo()
 
     menu.setCalendar(calendar);
     menu.showIncidencePopup(item, QDate());
-    QAction *createnote = menu.findChild<QAction *>(QStringLiteral("createnote"));
+    auto *createnote = menu.findChild<QAction *>(QStringLiteral("createnote"));
 
-    CalendarSupport::NoteEditDialog *noteedit = menu.findChild<CalendarSupport::NoteEditDialog *>();
+    auto *noteedit = menu.findChild<CalendarSupport::NoteEditDialog *>();
     QVERIFY(!noteedit);
     createnote->trigger();
     noteedit = menu.findChild<CalendarSupport::NoteEditDialog *>();
@@ -234,9 +223,9 @@ void KoEventPopupMenuTest::defaultMenuEventVisible()
 
     menu.setCalendar(calendar);
     menu.showIncidencePopup(item, QDate());
-    QAction *createevent = menu.findChild<QAction *>(QStringLiteral("createevent"));
-    QAction *createnote = menu.findChild<QAction *>(QStringLiteral("createnote"));
-    QAction *createtodo = menu.findChild<QAction *>(QStringLiteral("createtodo"));
+    auto *createevent = menu.findChild<QAction *>(QStringLiteral("createevent"));
+    auto *createnote = menu.findChild<QAction *>(QStringLiteral("createnote"));
+    auto *createtodo = menu.findChild<QAction *>(QStringLiteral("createtodo"));
     QVERIFY(!createevent->isVisible());
     QVERIFY(createnote->isVisible());
     QVERIFY(createtodo->isVisible());
@@ -255,9 +244,9 @@ void KoEventPopupMenuTest::defaultMenuTodoVisible()
 
     menu.setCalendar(calendar);
     menu.showIncidencePopup(item, QDate());
-    QAction *createevent = menu.findChild<QAction *>(QStringLiteral("createevent"));
-    QAction *createnote = menu.findChild<QAction *>(QStringLiteral("createnote"));
-    QAction *createtodo = menu.findChild<QAction *>(QStringLiteral("createtodo"));
+    auto *createevent = menu.findChild<QAction *>(QStringLiteral("createevent"));
+    auto *createnote = menu.findChild<QAction *>(QStringLiteral("createnote"));
+    auto *createtodo = menu.findChild<QAction *>(QStringLiteral("createtodo"));
     QVERIFY(createevent->isVisible());
     QVERIFY(createnote->isVisible());
     QVERIFY(!createtodo->isVisible());
