@@ -1,35 +1,18 @@
 /*
   This file is part of KOrganizer.
-  Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2002 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-  Author: Sergio Martins <sergio@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Sergio Martins <sergio@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "datenavigator.h"
 #include "koglobals.h"
 #include "korganizer_debug.h"
 
-#include <QDate>
 
 DateNavigator::DateNavigator(QObject *parent) : QObject(parent)
 {
@@ -50,7 +33,7 @@ int DateNavigator::datesCount() const
     return mSelectedDates.count();
 }
 
-void DateNavigator::selectDates(const KCalendarCore::DateList &dateList, const QDate &preferredMonth)
+void DateNavigator::selectDates(const KCalendarCore::DateList &dateList, QDate preferredMonth)
 {
     if (!dateList.isEmpty()) {
         mSelectedDates = dateList;
@@ -58,16 +41,14 @@ void DateNavigator::selectDates(const KCalendarCore::DateList &dateList, const Q
     }
 }
 
-void DateNavigator::selectDate(const QDate &date)
+void DateNavigator::selectDate(QDate date)
 {
-    QDate d = date;
-
-    if (!d.isValid()) {
+    if (!date.isValid()) {
         qCDebug(KORGANIZER_LOG) << "an invalid date was passed as a parameter!";
-        d = QDate::currentDate();
+        date = QDate::currentDate();
     }
     mSelectedDates.clear();
-    mSelectedDates.append(d);
+    mSelectedDates.append(date);
 
     emitSelected();
 }
@@ -91,7 +72,7 @@ void DateNavigator::selectDates(const QDate &d, int count, const QDate &preferre
     emitSelected(preferredMonth);
 }
 
-void DateNavigator::selectWeekByDay(int weekDay, const QDate &d, const QDate &preferredMonth)
+void DateNavigator::selectWeekByDay(int weekDay, QDate d, QDate preferredMonth)
 {
     int dateCount = mSelectedDates.count();
     bool weekStart = (weekDay == KOGlobals::self()->firstDayOfWeek());
@@ -126,7 +107,7 @@ void DateNavigator::selectWorkWeek()
     selectWorkWeek(mSelectedDates.first());
 }
 
-void DateNavigator::selectWorkWeek(const QDate &d)
+void DateNavigator::selectWorkWeek(QDate d)
 {
     const int weekStart = KOGlobals::self()->firstDayOfWeek();
     const int dayOfWeek = d.dayOfWeek();
