@@ -1,29 +1,13 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2002 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-  Author: Sergio Martins <sergio@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Sergio Martins <sergio@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef KORG_DATENAVIGATOR_H
@@ -50,8 +34,8 @@ public:
     Q_REQUIRED_RESULT int datesCount() const;
 
 public Q_SLOTS:
-    void selectDates(const KCalendarCore::DateList &, const QDate &preferredMonth = QDate());
-    void selectDate(const QDate &);
+    void selectDates(const KCalendarCore::DateList &, QDate preferredMonth = QDate());
+    void selectDate(QDate);
 
     void selectDates(int count);
     void selectDates(const QDate &, int count, const QDate &preferredMonth = QDate());
@@ -60,9 +44,9 @@ public Q_SLOTS:
     void selectWeek(const QDate &, const QDate &preferredMonth = QDate());
 
     void selectWorkWeek();
-    void selectWorkWeek(const QDate &);
+    void selectWorkWeek(QDate);
 
-    void selectWeekByDay(int weekDay, const QDate &, const QDate &preferredMonth = QDate());
+    void selectWeekByDay(int weekDay, QDate, QDate preferredMonth = QDate());
 
     void selectToday();
 
