@@ -1,27 +1,11 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2001 Eitzenberger Thomas <thomas.eitzenberger@siemens.at>
-  Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2001 Eitzenberger Thomas <thomas.eitzenberger@siemens.at>
+  SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef KORG_KODAYMATRIX_H
@@ -85,7 +69,7 @@ public:
     /** returns the first and last date of the 6*7 matrix that displays @p month
      * @param month The month we want to get matrix boundaries
      */
-    static Q_REQUIRED_RESULT QPair<QDate, QDate> matrixLimits(const QDate &month);
+    static Q_REQUIRED_RESULT QPair<QDate, QDate> matrixLimits(QDate month);
 
     /**
       Associate a calendar with this day matrix. If there is a calendar, the
@@ -101,7 +85,7 @@ public:
      *  @param actdate recalculates the day matrix to show NUMDAYS starting
      *  from this date.
      */
-    void updateView(const QDate &actdate);
+    void updateView(QDate actdate);
 
     /**
       Update incidence states of dates. Depending of the preferences days with
@@ -134,7 +118,7 @@ public:
      * @param start start of the new selection
      * @param end end date of the new selection
      */
-    void setSelectedDaysFrom(const QDate &start, const QDate &end);
+    void setSelectedDaysFrom(QDate start, QDate end);
 
     /**
       Clear all selections.
