@@ -1,26 +1,10 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "koeventpopupmenu.h"
@@ -400,7 +384,7 @@ void KOEventPopupMenu::createNote()
         newNoteItem.setMimeType(Akonadi::NoteUtils::noteMimeType());
         newNoteItem.setPayload(note.message());
 
-        CalendarSupport::NoteEditDialog *noteedit = new CalendarSupport::NoteEditDialog(this);
+        auto *noteedit = new CalendarSupport::NoteEditDialog(this);
         connect(noteedit, &CalendarSupport::NoteEditDialog::createNote,
                 this, &KOEventPopupMenu::slotCreateNote);
         noteedit->load(newNoteItem);
@@ -410,7 +394,7 @@ void KOEventPopupMenu::createNote()
 
 void KOEventPopupMenu::slotCreateNote(const Akonadi::Item &noteItem, const Akonadi::Collection &collection)
 {
-    Akonadi::ItemCreateJob *createJob = new Akonadi::ItemCreateJob(noteItem, collection, this);
+    auto *createJob = new Akonadi::ItemCreateJob(noteItem, collection, this);
     connect(createJob, &Akonadi::ItemCreateJob::result, this,
             &KOEventPopupMenu::slotCreateNewNoteJobFinished);
     createJob->start();
