@@ -1,26 +1,10 @@
 /*
   This file is part of Kontact.
 
-  Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>
-  Copyright (c) 2004,2009 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 2003 Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2004, 2009 Allen Winter <winter@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "sdsummarywidget.h"
@@ -118,7 +102,7 @@ SDSummaryWidget::SDSummaryWidget(KontactInterface::Plugin *plugin, QWidget *pare
 {
     mCalendar = CalendarSupport::calendarSingleton();
     // Create the Summary Layout
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setSpacing(3);
     mainLayout->setContentsMargins(3, 3, 3, 3);
 
@@ -232,7 +216,7 @@ int SDSummaryWidget::dayof(const KCalendarCore::Event::Ptr &event, const QDate &
 void SDSummaryWidget::slotBirthdayJobFinished(KJob *job)
 {
     // ;)
-    BirthdaySearchJob *bJob = qobject_cast<BirthdaySearchJob *>(job);
+    auto *bJob = qobject_cast<BirthdaySearchJob *>(job);
     if (bJob) {
         const auto items = bJob->items();
         for (const Akonadi::Item &item : items) {
@@ -553,7 +537,7 @@ void SDSummaryWidget::createLabels()
 
             // Description
             if ((*addrIt).type == IncidenceTypeContact) {
-                KUrlLabel *urlLabel = new KUrlLabel(this);
+                auto *urlLabel = new KUrlLabel(this);
                 urlLabel->installEventFilter(this);
                 urlLabel->setUrl((*addrIt).item.url(Akonadi::Item::UrlWithMimeType).url());
                 urlLabel->setText((*addrIt).addressee.realName());
@@ -636,7 +620,7 @@ void SDSummaryWidget::updateView()
 
     // Search for Birthdays
     if (mShowBirthdaysFromKAB && !mJobRunning) {
-        BirthdaySearchJob *job = new BirthdaySearchJob(this, mDaysAhead);
+        auto *job = new BirthdaySearchJob(this, mDaysAhead);
 
         connect(job, &BirthdaySearchJob::result, this, &SDSummaryWidget::slotBirthdayJobFinished);
         job->start();
@@ -654,7 +638,7 @@ void SDSummaryWidget::mailContact(const QString &url)
         return;
     }
 
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, this);
+    auto *job = new Akonadi::ItemFetchJob(item, this);
     job->fetchScope().fetchFullPayload();
     connect(job, &Akonadi::ItemFetchJob::result, this, &SDSummaryWidget::slotItemFetchJobDone);
 }
@@ -707,7 +691,7 @@ void SDSummaryWidget::popupMenu(const QString &url)
 bool SDSummaryWidget::eventFilter(QObject *obj, QEvent *e)
 {
     if (obj->inherits("KUrlLabel")) {
-        KUrlLabel *label = static_cast<KUrlLabel *>(obj);
+        auto *label = static_cast<KUrlLabel *>(obj);
         if (e->type() == QEvent::Enter) {
             Q_EMIT message(i18n("Mail to:\"%1\"", label->text()));
         }
